@@ -3,7 +3,7 @@
 ###
 ### unit test for Converter
 ###
-### $Id: converter-test.rb 52 2005-03-06 23:15:41Z kwatch $
+### $Id: converter-test.rb 94 2005-06-27 14:12:08Z kwatch $
 ###
 
 $: << 'lib'
@@ -1654,6 +1654,34 @@ END
     end
 
 
+    def test_convert_replace2	# replace:foo:element
+	input = <<-'END'
+		<div kw:d="replace:foo:element">
+		foo
+		</div>
+	END
+	expected = <<-'END'
+		:block
+		  @element(foo)
+	END
+	_test_convert(input, expected)
+    end
+
+
+    def test_convert_replace3	# replace:foo:content
+	input = <<-'END'
+		<div kw:d="replace:foo:content">
+		foo
+		</div>
+	END
+	expected = <<-'END'
+		:block
+		  @content(foo)
+	END
+	_test_convert(input, expected)
+    end
+
+
     def test_convert_placeholder1	# placeholder
 	input = <<-'END'
 		<div id="placeholder:foo">
@@ -1672,6 +1700,53 @@ END
     end
 
 
+    def test_convert_placeholder2	# placeholder:foo:element
+	input = <<-'END'
+		<div id="placeholder:foo:element">
+		foo
+		</div>
+	END
+	expected = <<-'END'
+		:block
+		  :print
+		    "<div>\n"
+		  @element(foo)
+		  :print
+		    "</div>\n"
+	END
+	_test_convert(input, expected)
+    end
+
+
+    def test_convert_placeholder3	# placeholder:foo:content
+	input = <<-'END'
+		<div id="placeholder:foo:content">
+		foo
+		</div>
+	END
+	expected = <<-'END'
+		:block
+		  :print
+		    "<div>\n"
+		  @content(foo)
+		  :print
+		    "</div>\n"
+	END
+	_test_convert(input, expected)
+    end
+
+
+    def test_convert_placeholder4	# placeholder with empty tag 
+	input = <<-'END'
+		<div id="placeholder:foo:content"/>
+	END
+	expected = ""
+	assert_raise(Kwartz::ConvertionError) do
+	    _test_convert(input, expected)
+	end
+    end
+
+
     def test_convert_include1	# include pdata file
 	input = <<-'END'
 		<html>
@@ -1752,15 +1827,13 @@ END
 		[content]
 		:block
 		  :print
-		    "  copyright&copy;"
+		    "  copyright&copy; "
 		  :print
-		    " "
 		  :print
 		    year
 		  :print
-		    " "
 		  :print
-		    "kuwata-lab all rights reserverd\n"
+		    " kuwata-lab all rights reserverd\n"
 		[spaces]
 		["", "\n", "", "\n"]
 		[plogic]
@@ -1775,15 +1848,13 @@ END
 		[content]
 		:block
 		  :print
-		    "  copyright&copy;"
+		    "  copyright&copy; "
 		  :print
-		    " "
 		  :print
 		    year
 		  :print
-		    " "
 		  :print
-		    "kuwata-lab all rights reserverd\n"
+		    " kuwata-lab all rights reserverd\n"
 		[spaces]
 		["", "\n", "", "\n"]
 		[plogic]
@@ -1798,15 +1869,13 @@ END
 		[content]
 		:block
 		  :print
-		    "  copyright&copy;"
+		    "  copyright&copy; "
 		  :print
-		    " "
 		  :print
 		    year
 		  :print
-		    " "
 		  :print
-		    "kuwata-lab all rights reserverd\n"
+		    " kuwata-lab all rights reserverd\n"
 		[spaces]
 		["", "\n", "", "\n"]
 		[plogic]
@@ -1829,6 +1898,74 @@ END
     end
 
 
+
+    def test_convert_span1	# span
+	input = <<-'END'
+		Hello  <div id="mark:user1">  World  </div>  !
+		Hello  <span id="mark:user2">  World  </span>  !
+		Hello  <div id="value:user3">  World  </div>  !
+		Hello  <span id="value:user4">  World  </span>  !
+	END
+	expected = <<-'END'
+		:block
+		  :print
+		    "Hello  "
+		  @element(user1)
+		  :print
+		    "  !\nHello  "
+		  @element(user2)
+		  :print
+		    "  !\nHello  "
+		  :print
+		    "<div>"
+		  :print
+		    user3
+		  :print
+		    "</div>"
+		  :print
+		    "  !\nHello  "
+		  :print
+		  :print
+		    user4
+		  :print
+		  :print
+		    "  !\n"
+		===== marking=user1 =====
+		[tagname]
+		div
+		[attrs]
+		[content]
+		:block
+		  :print
+		    "  World  "
+		[spaces]
+		["", "", "", ""]
+		[plogic]
+		:block
+		  @stag
+		  @cont
+		  @etag
+		===== marking=user2 =====
+		[tagname]
+		span
+		[attrs]
+		[content]
+		:block
+		  :print
+		    "  World  "
+		[spaces]
+		["", "", "", ""]
+		[plogic]
+		:block
+		  @stag
+		  @cont
+		  @etag
+	END
+	_test_convert(input, expected)
+    end
+
+
+
     def test_convert_properties1	# 'even' and 'odd'
 	input = <<-'END'
 		<tbody kw:d="LOOP:item:list">
