@@ -3,7 +3,7 @@
 ###
 ### unit test for Parser
 ###
-### $Id: parser-test.rb 68 2005-04-26 11:01:50Z kwatch $
+### $Id: parser-test.rb 96 2005-06-29 03:58:35Z kwatch $
 ###
 
 $: << 'lib'
@@ -885,21 +885,64 @@ END
 
 
    ##
-   def test_parse_expand_stmt1  # @stag
-      input = "@stag;"
-      expected = <<'END'
-@stag
+   def test_parse_if_stmt6       # 'elseif' and 'else if'
+      input = <<'END'
+if (x > 10)     y = 10;
+elseif (x > 5)  y = 5;
+else if (x > 0) y = 0;
 END
+      expected = <<'END'
+:if
+  >
+    x
+    10
+  :expr
+    =
+      y
+      10
+  :if
+    >
+      x
+      5
+    :expr
+      =
+        y
+        5
+    :if
+      >
+        x
+        0
+      :expr
+        =
+          y
+          0
+END
+      _test(input, expected)
+   end
+
+
+
+   ##
+   def test_parse_expand_stmt1  # @stag, @cont, @etag
+      input = "@stag;"
+      expected = "@stag\n"
+      _test(input, expected, ExpandStatement)
+      input = "@cont;"
+      expected = "@cont\n"
+      _test(input, expected, ExpandStatement)
+      input = "@etag;"
+      expected = "@etag\n"
       _test(input, expected, ExpandStatement)
    end
 
 
    ##
-   def test_parse_expand_stmt2  # @element(foo)
+   def test_parse_expand_stmt2  # @element(foo), @content(foo)
       input = "@element(foo);"
-      expected = <<'END'
-@element(foo)
-END
+      expected = "@element(foo)\n"
+      _test(input, expected, ExpandStatement)
+      input = "@content(foo);"
+      expected = "@content(foo)\n"
       _test(input, expected, ExpandStatement)
    end
 
