@@ -1,7 +1,7 @@
 #!/usr/bin/ruby
 
 ###
-### $Id: test.rb 77 2005-05-08 19:40:52Z kwatch $
+### $Id: test.rb 83 2005-06-13 13:31:53Z kwatch $
 ###
 
 $: << 'test'
@@ -34,6 +34,9 @@ suite << ParseDeclarationTest.suite()
 require 'element-test'
 suite << ElementTest.suite()
 
+require 'expander-test'
+suite << ExpanderTest.suite()
+
 require 'translator-test'
 suite << TranslatorTest.suite()
 
